@@ -85,7 +85,7 @@ This module is not intended to be used directly.
 =head1 DEPENDENCIES
 
 RPC::ExtDirect::Deserialize is dependent on the following modules:
-    JSON
+L<JSON>
 
 =head1 AUTHOR
 
@@ -93,9 +93,10 @@ Alexander Tokarev E<lt>tokarev@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011 Alexander Tokarev.
+Copyright (c) 2011-2012 Alexander Tokarev.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See L<perlartistic>.
 
 =cut
+
